/*
 Project:     Temperature and relative humidity meter using Si7005
 Description: Receives temperature and relative humidity bytes from USB-UART port and displays the
              info on a graphics window. 
 Written by:  Rajendra Bhatt (www.embedded-lab.com)
 Date:        2013/12/06     

*/

//import Serial communication library
import processing.serial.*;

// Declare variable "a" of type PImage
PImage a;  

// Variable declaration
PFont font22, font44, font48;
PFont font12;
float tempC, tempF, RH;
float y, h, MS_Byte, LS_Byte;
Serial Dev_Board;
PrintWriter output;
int[] PC_Time = new int[3];
int[] MM_DD_YY = new int[3];
int i, j, xx=-15;
String curr_time, X_Time, curr_date, row_data, filename;
String[] message = new String[2];
// Button
int rectX, rectY;      // Position of square button
int rectSize = 90;     // Diameter of rect
color rectColor, baseColor;
color rectHighlight;
color currentColor;
boolean rectOver = false, data_logg = false ;


void setup() {

// Define size of window
size(350, 350);

  //setup fonts for use throughout the application
  font22 = loadFont("MicrosoftYaHei-22.vlw");
  font12 = loadFont("MicrosoftYaHei-12.vlw");  
  font44 = loadFont("FranklinGothic-Demi-32.vlw");
  font48 = loadFont("GillSansMT-48.vlw");
  //init serial communication port
  Dev_Board = new Serial(this, "COM4", 9600);
  Dev_Board.bufferUntil(13);
  smooth();
  rectColor = color(0, 90, 140);
  rectHighlight = color(80);
  rectX = 220;
  rectY = 250;
  ellipseMode(CENTER);
  a=loadImage("waterdrop.jpg");
 
}

void draw() {
 serialEvent();
}
 

void serialEvent()
{
  for(int i=0;i<2;i++)
  {
 message[i] = Dev_Board.readStringUntil(13);
           if(message[i] != null)
               {
               float value = float(message[i]);
               println(value);
                }
  delay(1);
  }
  if(message[0] != null && message[1] != null)
  { 
    tempC = float(message[0]);
    RH = round(float(message[1]));

  }
 
 
  
  background(255, 255, 255); 
 fill(200, 6, 0);
 smooth();
 stroke(0);
 strokeWeight(2);
 ellipse(100, 280, 58, 50);
 noStroke();
 fill(0, 46, 200);
 arc(100, 60, 30, 20, PI, PI+PI);
 rect(85,60,30,200);
 // Capillary
 fill(250,250, 250);
 //stroke(0);
 rect(95,60,10,200);

 // Marks on thermometer
 stroke(0);
 strokeWeight(1);
 textAlign(RIGHT);
 fill(0,46,250);
 for (int i = 0; i < 5; i += 1) {
  line(70, 230-40*i, 80, 230-40*i);
  if(i < 4) line(75, 210-40*i, 80, 210-40*i);
  textFont(font12); 
  text(str(40+20*i), 65, 235-40*i); 
 }
 image(a, 180, 130);
 // Centigrade
 textAlign(LEFT);
 for (int i = 0; i < 6; i += 1) {
  line(118, 242-35*i, 128, 242-35*i);
  if(i < 5) line(118, 225-35*i, 123, 225-35*i);
  textFont(font12); 
  text(str(0+10*i), 135, 247-35*i);
 }

 noStroke();
 // text font
 fill(0,46,250);

 textFont(font22); 
 textAlign(LEFT);
 text("F", 57, 46);
 text("C", 135, 46);
 textFont(font12);
 text("o", 45, 35);
 text("o", 125, 35);

 fill(0,102,153);
 textFont(font22);
 text("o", 300+xx, 45);
 text("o", 300+xx, 85);

 tempF = ((tempC*9)/5) + 32;
 textFont(font44); 
 text(nfc(tempC, 1), 220+xx, 60);
 text(nfc(tempF, 1), 220+xx, 100);
 text("C", 320+xx, 60);
 text("F", 320+xx, 100);
 
 // Print Relative Humidity
 textFont(font48);
 text(nfc(RH, 0), 245, 190);
 text("%",295 , 190);
 // Raise mercury level
 fill(200,0, 0);
 y = -2.0*tempF + 310;
 h = 270-y;
 rect(95, y, 10, h);
 
}

